@@ -30,19 +30,20 @@ class Optimizer:
     """
         Base class for starting an optimization
     """
-    def __init__(self,name:str,eval_script:str, eval_folder:str = None,opt_folder:str=None, eval_parameters:List[Parameter]=[], objectives:List[Parameter] = [], performance_parameters:List[Parameter] = [], single_folder_eval=False):
+    def __init__(self,name:str,eval_command:str, eval_folder:str = None,opt_folder:str=None, eval_parameters:List[Parameter]=[], objectives:List[Parameter] = [], performance_parameters:List[Parameter] = [], single_folder_eval=False, overwrite_input_file=False):
         """Initializes the optimizer. This is typically inherited by a particular type of optimizer like NSGA (multi-objective differential evolution) or SODE (single objective differential evolution). Any new optimization strategy should inherit from this class.
         This class handles most of the heavy work of evaluation and reading the results.
 
         Args:
             name (str): name of the optimizer
-            eval_script (str): This is the location of the evaluation script. Optimizer will call this script and read output.txt containing the values of the objectives and any performance parameters, see examples. 
+            eval_command (str): This is the location of the evaluation script. Optimizer will call this script and read output.txt containing the values of the objectives and any performance parameters, see examples. 
             eval_folder (str, optional): If specified, the evaluation folder will be copied for each execution. Defaults to None.
             opt_folder (str, optional): Working directory where you want to start the optimization (calculatio folder will be created here). Defaults to None.
             eval_parameters (List[Parameter], optional): This is the list of x1-xn that feeds into your execution code. Defaults to [].
             objectives (List[Parameter], optional): The objectives you want to keep track of and the value for when they fail. Defaults to [].
             performance_parameters (List[Parameter], optional): Number of parameters. Defaults to [].
             single_folder_eval (bool, optional): Saves space by deleting the population folder when completed. by default this is false. Defaults to False.
+            overwrite_input_file(bool, optional): Specifies whether or not to overwrite the input file when restarting a simulation. Defaults to False.
 
         Raises:
             Exception: Invalid relative path could not be found for eval script
@@ -56,25 +57,17 @@ class Optimizer:
         logging.basicConfig(filename=os.path.join(opt_folder,'log.dat'),  level=logging.DEBUG)
         self.logger = logging.getLogger()
 
-        if (not os.path.isabs(eval_script)):
-            eval_script = os.path.join(os.getcwd(),eval_script)
-            if (not os.path.isfile(eval_script)):
-                raise Exception('Invalid relative path could not be found for eval script {0}'.format(eval_script))
-
         if (not os.path.isabs(eval_folder)):
             eval_folder = os.path.join(os.getcwd(),eval_folder)
             if (not os.path.isdir(eval_folder)):
                 raise Exception('Invalid relative path could not be found for eval folder {0}'.format(eval_folder))
 
-        if (not os.path.isfile(eval_script)):
-            raise Exception('Invalid absolute path could not be found for eval script {0}'.format(eval_script))
-
         if (not os.path.isdir(eval_folder)):
             raise Exception('Invalid absolute path could not be found for eval folder {0}'.format(eval_folder))
 
 
         self.evaluation_folder = eval_folder
-        self.evaluation_script = eval_script
+        self.evaluation_command = eval_command
 
         if (opt_folder):
             self.optimization_folder = opt_folder
@@ -82,10 +75,11 @@ class Optimizer:
             self.optimization_folder = os.getcwd()        
         
         if (not os.path.isabs(self.optimization_folder)):
-            self.optimization_folder = os.path.join(os.getcwd(),eval_script)
+            self.optimization_folder = os.getcwd()
 
 
         self.population_track = []
+        self.overwrite_input_file = overwrite_input_file
         self.input_file = 'input.dat'
         self.output_file = 'output.txt'
         self.__use_calculation_folders = True
@@ -162,28 +156,35 @@ class Optimizer:
         """
         self.__parallel_settings = settings
         # Check for machine file
-        machinefile = os.path.join(self.optimization_folder,settings.machine_filename)
+        machinefile = os.path.join(self.optimization_folder,settings.machine_filename)        
         if os.path.exists(machinefile):
             with open(machinefile, 'r') as f:
                 x = f.read().splitlines()
                 temp = []
                 for i in range(len(x)):
                     temp.append(x[i])
-                    if (i+1) % self.__parallel_settings.cores_per_execution == 0:
-                        self.cores_per_evalulation.append(copy.deepcopy(temp))   # Splits up the machine file
-                        temp.clear()
+                    if self.__parallel_settings.cores_per_execution > 0:
+                        if (i+1) % self.__parallel_settings.cores_per_execution == 0:
+                            self.cores_per_evalulation.append(copy.deepcopy(temp))   # Splits up the machine file
+                            temp.clear()
                     
 
     def __create_input_file__(self,individual:Individual):
-        """Creates an input file 'inputs.txt' which the evaluation script reads
+        """Creates an input file 'inputs.txt' which the evaluation script reads. Will only  create if inputs.txt does not already exist
 
         Args:
             individual (Individual): Individual's evaluation parameters are read x[1-N] are printed to an evaluation script
         """
-        with open(self.input_file,'w') as f:
-            eval_params = individual.get_eval_parameter_list()
-            for p in range(len(eval_params)):
-                f.write('{0} = {1}\n'.format(eval_params[p].name,eval_params[p].value))
+        def write_input():
+            with open(self.input_file,'w') as f:
+                eval_params = individual.get_eval_parameter_list()
+                for p in range(len(eval_params)):
+                    f.write('{0} = {1}\n'.format(eval_params[p].name,eval_params[p].value))
+
+        if os.path.exists(self.input_file) and self.overwrite_input_file:
+            write_input()
+        else:       # input file does not exists
+            write_input()
        
     def __read_output_file__(self, individual:Individual) -> Individual:
         """Reads the output file i.e. output.txt line by line and parses it for objectives and parameters
@@ -364,7 +365,7 @@ class Optimizer:
                         del pid_list[index]  
                     
             else: # TODO execute individual without creating a bunch of directories. Maybe create execution directories and delete them
-                output = subprocess.check_output(['python', self.evaluation_script])
+                output = subprocess.check_output([self.evaluation_command])
                 # Append output to results, need to check first how the output is structured
         time.sleep(0.1)
     
@@ -433,7 +434,7 @@ class Optimizer:
                     f.write('\n'.join(cores_per_execution))
                     
             # Evaluate
-            p = subprocess.Popen(['python', self.evaluation_script],stdout=subprocess.PIPE, stderr=subprocess.STDOUT) # Note: evaluation_script has to read the local machine file. This is not my problem            
+            p = subprocess.Popen(self.evaluation_command.split(' '),stdout=subprocess.PIPE, stderr=subprocess.STDOUT) # Note: evaluation_command has to read the local machine file. This is not my problem            
             os.chdir(cur_dir)
             return p.pid, p
         return -1,None
@@ -623,25 +624,35 @@ class Optimizer:
         head = 'VARIABLES = ' + ','.join(variables) + '\n'
 
         # zones
-        data_str = ' '
+        
         zones = []
+        i = 0
         for key, df in self.pandas_cache.items():
-            zone_str = 'ZONE T = \"{0}\"\n'.format(key+"_"+df.iloc[0]['name'])
-            for index, row in self.df.iterrows():
+            zone_str = 'ZONE T = \"{0}\"\n'.format(key+"_"+df.iloc[0]['individual'])
+            data_str = ' '
+            for index, row in self.pandas_cache[key].iterrows():
                 data = []
-                for col in self.df.columns:
-                    if (col != 'name'):
-                        data.append(row[col])
-                data_str = ' '.join(data) + '\n'
-
-            zones.append(zone_str)
-            zones.append(data_str)
+                for col in self.pandas_cache[key].columns:
+                    if col=='population':
+                        if row[col] == "DOE":
+                            data.append(str(-1))
+                        else:
+                            data.append(str(row[col].replace('POP','')))
+                    elif col=="individual":
+                        data.append(str(row[col].replace('IND','')))
+                    else:
+                        if type(row[col])== float:
+                            data.append("{:.6E}".format(row[col]))
+                        else:
+                            data.append(row[col])
+                zones.append(zone_str)
+                zones.append(' '.join(data) + '\n')
         
         # write to .tec file
-        if (not os.path.exists(os.path.join(self.optimization_folder,'Database'))):
-            os.makedirs(os.path.join(self.optimization_folder,'Database'))
+        if (not os.path.exists(os.path.join(self.optimization_folder,''))):
+            os.makedirs(os.path.join(self.optimization_folder,''))
 
-        db_filename = os.path.join(self.optimization_folder,'Database','database.tec')
+        db_filename = os.path.join(self.optimization_folder,'','database.tec')
         with open(db_filename,'w') as f:
             # write headers
             f.write(head)
